<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>اسم البطاقة</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="47"/>
        <source>Profile:</source>
        <translation>الملف الشخصي:</translation>
    </message>
    <message>
        <location filename="../cardwidget.cc" line="67"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>فشل pa_context_set_card_profile_by_index()</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%1% (%2dب)</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%1%</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;صمت&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;دقيقه&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;100٪ (0 ديسيبل)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;قاعدة&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <location filename="../channelwidget.ui" line="14"/>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="20"/>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation>&lt;b&gt;الجبهة اليسرى&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="34"/>
        <source>&lt;small&gt;50%&lt;/small&gt;</source>
        <translation>&lt;small&gt;50%&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>عنوان الجهاز</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>كتم الصوت</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>قفل القنوات معا</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>تعيين كاحتياطي</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;منفذ:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>عرض الخيارات المتقدمة</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>AC3</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>EAC3</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>DTS</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>MPEG</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;إزاحة وقت الإستجابة:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> م‌ث</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="42"/>
        <source>Rename device...</source>
        <translation>إعادة تسمية الجهاز...</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="156"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>فشل pa_context_set_port_latency_offset()</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="227"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>عذرا، ولكن إعادة تسمية الجهاز غير مدعومة.</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="228"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>تحتاج إلى تحميل وحدة إدارة الأجهزة في خادم PulseAudio من أجل إعادة تسمية الأجهزة</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="234"/>
        <source>Rename device %1 to:</source>
        <translation>إعادة تسمية الجهاز %1 إلى:</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="241"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>فشل pa_ext_device_manager_set_device_description()</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>التحكم في مستوى الصوت</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;لا يوجد تطبيق يقوم حاليا بتشغيل الصوت.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>عرض:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <location filename="../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>جميع التدفقات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <location filename="../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>التطبيقات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <location filename="../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>التدفقات الافتراضية</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;لا يوجد تطبيق يقوم حاليا بتسجيل الصوت.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;لا تتوفر أجهزة إخراج&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>جميع أجهزة الإخراج</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>أجهزة إخراج الأجهزة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>أجهزة الإخراج الافتراضية</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>&amp;تشغيل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;التسجيل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>&amp;أجهزة الإخراج</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>&amp;أجهزة الإدخال</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;لا تتوفر أجهزة إدخال&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>جميع أجهزة الإدخال</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>الكل ما عدا الشاشات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>أجهزة إدخال الأجهزة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>أجهزة الإدخال الافتراضية</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>مراقب</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;الاعدادات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;لا توجد بطاقات متاحة للاعداد&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>إظهار مقاييس مستوى الصوت</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (متصل)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="163"/>
        <location filename="../mainwindow.cc" line="259"/>
        <source> (unavailable)</source>
        <translation> (غير متوفر)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="165"/>
        <location filename="../mainwindow.cc" line="256"/>
        <source> (unplugged)</source>
        <translation> (غير موصول)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="390"/>
        <source>Failed to read data from stream</source>
        <translation>فشل في قراءة البيانات من البث</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="434"/>
        <source>Peak detect</source>
        <translation>كشف الذروة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="435"/>
        <source>Failed to create monitoring stream</source>
        <translation>فشل في إنشاء دفق مراقبة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="450"/>
        <source>Failed to connect monitoring stream</source>
        <translation>فشل في توصيل دفق المراقبة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="590"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>تجاهل إدخال الحوض بسبب تعيينه كحدث وبالتالي التعامل معه بواسطة عنصر واجهة مستخدم الحدث</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="762"/>
        <source>System Sounds</source>
        <translation>أصوات النظام</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="1092"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>إنشاء اتصال ب PulseAudio. الرجاء الانتظار...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../pavucontrol.cc" line="66"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="87"/>
        <source>Card callback failure</source>
        <translation>فشل معاودة الاتصال بالبطاقة</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="110"/>
        <source>Sink callback failure</source>
        <translation>فشل معاودة الاتصال بالحوض</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="133"/>
        <source>Source callback failure</source>
        <translation>فشل رد الاتصال بالمصدر</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="152"/>
        <source>Sink input callback failure</source>
        <translation>فشل معاودة الاتصال بإدخال الحوض</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="171"/>
        <source>Source output callback failure</source>
        <translation>فشل معاودة الاتصال بإخراج المصدر</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="211"/>
        <source>Client callback failure</source>
        <translation>فشل معاودة الاتصال بالعميل</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="227"/>
        <source>Server info callback failure</source>
        <translation>فشل معاودة الاتصال بمعلومات الخادم</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="245"/>
        <location filename="../pavucontrol.cc" line="542"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>فشل تهيئة ملحق stream_restore: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="263"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>فشل pa_ext_stream_restore_read()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="281"/>
        <location filename="../pavucontrol.cc" line="556"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>فشل تهيئة ملحق استعادة الجهاز: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="302"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>فشل pa_ext_device_restore_read_sink_formats()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="320"/>
        <location filename="../pavucontrol.cc" line="569"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>فشل تهيئة ملحق إدارة الأجهزة: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="339"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>فشل pa_ext_device_manager_read()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="356"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>فشل pa_context_get_sink_info_by_index()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="369"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>فشل pa_context_get_source_info_by_index()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="382"/>
        <location filename="../pavucontrol.cc" line="395"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>فشل pa_context_get_sink_input_info()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="408"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>فشل pa_context_get_client_info()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="418"/>
        <location filename="../pavucontrol.cc" line="483"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>فشل pa_context_get_server_info()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="431"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>فشل pa_context_get_card_info_by_index()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="474"/>
        <source>pa_context_subscribe() failed</source>
        <translation>فشل pa_context_subscribe()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="490"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>فشل pa_context_client_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="497"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>فشل pa_context_get_card_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="504"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>فشل pa_context_get_sink_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="511"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>فشل pa_context_get_source_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="518"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>فشل pa_context_get_sink_input_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="525"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>فشل pa_context_get_source_output_info_list()</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="584"/>
        <location filename="../pavucontrol.cc" line="635"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>فشل الاتصال، في محاولة لإعادة الاتصال</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="607"/>
        <location filename="../pavucontrol.cc" line="664"/>
        <source>PulseAudio Volume Control</source>
        <translation>التحكم في مستوى الصوت PulseAudio</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="622"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s.&lt;br&gt;&lt;br&gt;In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Propertiesor default-server in client.conf is misconfigured.&lt;br&gt;This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.&lt;br&gt;If this is the case, then PulseAudio should autospawn again, or if this is not configured you shouldrun start-pulseaudio-x11 manually.</source>
        <translation>فشل الاتصال بـ PulseAudio. إعادة المحاولة تلقائيًا في 5 ثوانٍ. &lt;br&gt; &lt;br&gt; في هذه الحالة ، من المحتمل أن يكون هذا بسبب خطأ PULSE_SERVER في البيئة / خصائص نافذة الجذر X11 أو الخادم الافتراضي في client.conf. &lt;br&gt; يمكن أن يحدث هذا الموقف أيضًا عند تعطل PulseAudio ومغادرته التفاصيل التي لا معنى لها في نافذة الجذر X11. &lt;br&gt; إذا كانت هذه هي الحالة ، فيجب عندئذٍ نشر PulseAudio تلقائيًا مرة أخرى ، أو إذا لم تتم تهيئتها ، فيجب تشغيل start-pulseaudio-x11 يدويًا.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="672"/>
        <source>Select a specific tab on load.</source>
        <translation>حدد علامة تبويب معينة عند التحميل.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="675"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>أعد المحاولة إلى الأبد إذا استقال PA (كل 5 ثوان).</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="678"/>
        <source>Maximize the window.</source>
        <translation>تكبير النافذة.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="703"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>خطأ فادح: غير قادر على الاتصال ب PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>فشل pa_ext_stream_restore_write()</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>في</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>إنهاء التشغيل</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="52"/>
        <source>Unknown output</source>
        <translation>إخراج غير معروف</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="63"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>فشل pa_context_set_sink_input_volume()</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="78"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>فشل pa_context_set_sink_input_mute()</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="88"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>فشل pa_context_kill_sink_input()</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="113"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>فشل pa_context_move_sink_input_by_index()</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>فشل pa_context_set_sink_volume_by_index()</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>فشل pa_context_set_sink_mute_by_index()</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>فشل pa_context_set_default_sink()</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>فشل pa_context_set_sink_port_by_index()</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>فشل pa_ext_device_restore_save_sink_formats()</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../sourceoutputwidget.cc" line="35"/>
        <source>from</source>
        <translation>من</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>إنهاء التسجيل</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="59"/>
        <source>Unknown input</source>
        <translation>إدخال غير معروف</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="71"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>فشل pa_context_set_source_output_volume()</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="86"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>فشل pa_context_set_source_output_mute()</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="97"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>فشل pa_context_kill_source_output()</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="124"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>فشل pa_context_move_source_output_by_index()</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>فشل pa_context_set_source_volume_by_index()</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>فشل pa_context_set_source_mute_by_index()</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>فشل pa_context_set_default_source()</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>فشل pa_context_set_source_port_by_index()</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>عنوان الجهاز</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>اتجاه</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>كتم الصوت</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>قفل القنوات معا</translation>
    </message>
    <message>
        <location filename="../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>فصل من العمل</translation>
    </message>
</context>
</TS>
